@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -148,3 +148,14 @@ class EchoFormat(TextFileFormat):
 
 EchoDirectoryFormat = model.SingleFileDirectoryFormat(
     'EchoDirectoryFormat', 'echo.txt', EchoFormat)
+
+
+class Cephalapod(TextFileFormat):
+    """
+    Class that inherits from text file format.
+    Used for testing validator sorting.
+    """
+
+
+CephalapodDirectoryFormat = model.SingleFileDirectoryFormat(
+    'CephalapodDirectoryFormat', 'squids.tsv', Cephalapod)
