@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -65,7 +65,7 @@ class ModelType:
 
         def transformation(view, validate_level='min'):
             view = self.coerce_view(view)
-            self.validate(view, validate_level)
+            self.validate(view, level=validate_level)
 
             new_view = transformer(view)
 
