@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -592,7 +592,7 @@ class UnionExp(_IdentityExpBase):
 
         if groups:
             elements = []
-            for canidate, group in groups.items():
+            for candidate, group in groups.items():
                 if len(group) == 1:
                     elements.append(group[0])
                 else:
