@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -8,7 +8,7 @@
 
 import pickle
 import unittest
-import collections
+import collections.abc
 
 import qiime2.core.type.grammar as grammar
 import qiime2.core.type.template as template
@@ -291,7 +291,7 @@ class TestTypeExp(unittest.TestCase):
         Z = MockTemplate('Z')
         P = MockPredicate('P')
 
-        self.assertIsInstance(X, collections.Hashable)
+        self.assertIsInstance(X, collections.abc.Hashable)
         # There really shouldn't be a collision between these:
         self.assertNotEqual(hash(X), hash(Z % P))
 
@@ -626,6 +626,11 @@ class TestUnion(unittest.TestCase):
             repr(Foo % P | Bar % Q | Foo % R | Bar % S),
             'Foo % (P | R) | Bar % (Q | S)')
 
+        self.assertEqual(
+            repr(grammar.UnionExp(
+                 [Foo % P, Bar % Q, Foo % R, Bar % S]).normalize()),
+            'Foo % (P | R) | Bar % (Q | S)')
+
     def test_maximum_antichain(self):
         P = MockPredicate('P', alphabetize=True)
         Q = MockPredicate('Q', alphabetize=True)
