@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -15,9 +15,11 @@ from qiime2.sdk.plugin_manager import GetFormatFilters
 
 from qiime2.core.testing.type import (IntSequence1, IntSequence2, IntSequence3,
                                       Mapping, FourInts, Kennel, Dog, Cat,
-                                      SingleInt, C1, C2, C3, Foo, Bar, Baz)
+                                      SingleInt, C1, C2, C3, Foo, Bar, Baz,
+                                      AscIntSequence, Squid, Octopus,
+                                      Cuttlefish)
 
-from qiime2.core.testing.format import (IntSequenceDirectoryFormat,
+from qiime2.core.testing.format import (Cephalapod, IntSequenceDirectoryFormat,
                                         MappingDirectoryFormat,
                                         IntSequenceV2DirectoryFormat,
                                         IntSequenceFormatV2,
@@ -26,7 +28,12 @@ from qiime2.core.testing.format import (IntSequenceDirectoryFormat,
                                         IntSequenceFormat,
                                         RedundantSingleIntDirectoryFormat,
                                         EchoFormat,
-                                        EchoDirectoryFormat)
+                                        EchoDirectoryFormat,
+                                        CephalapodDirectoryFormat)
+
+from qiime2.core.testing.validator import (validator_example_null1,
+                                           validate_ascending_seq,
+                                           validator_example_null2)
 
 from qiime2.core.testing.util import get_dummy_plugin
 
@@ -43,40 +50,67 @@ class TestPluginManager(unittest.TestCase):
         exp = {'dummy-plugin': self.plugin}
         self.assertEqual(plugins, exp)
 
+    def test_validators(self):
+        self.assertEqual({Kennel[Dog], Kennel[Cat], AscIntSequence, Squid,
+                          Octopus, Cuttlefish},
+                         set(self.pm.validators))
+
+        self.assertEqual(
+            set([r.validator for r in
+                self.pm.validators[Kennel[Dog]]._validators]),
+            {validator_example_null1, validator_example_null2})
+
+        self.assertEqual(
+            [r.validator for r in self.pm.validators[Kennel[Cat]]._validators],
+            [validator_example_null1])
+
+        self.assertEqual(
+            [r.validator
+             for r in self.pm.validators[AscIntSequence]._validators],
+            [validate_ascending_seq])
+
     def test_type_fragments(self):
         types = self.pm.type_fragments
 
         exp = {
-            'IntSequence1': SemanticTypeRecord(semantic_type=IntSequence1,
-                                               plugin=self.plugin),
-            'IntSequence2': SemanticTypeRecord(semantic_type=IntSequence2,
-                                               plugin=self.plugin),
-            'IntSequence3': SemanticTypeRecord(semantic_type=IntSequence3,
-                                               plugin=self.plugin),
-            'Mapping':      SemanticTypeRecord(semantic_type=Mapping,
-                                               plugin=self.plugin),
-            'FourInts':     SemanticTypeRecord(semantic_type=FourInts,
-                                               plugin=self.plugin),
-            'Kennel':       SemanticTypeRecord(semantic_type=Kennel,
-                                               plugin=self.plugin),
-            'Dog':          SemanticTypeRecord(semantic_type=Dog,
-                                               plugin=self.plugin),
-            'Cat':          SemanticTypeRecord(semantic_type=Cat,
-                                               plugin=self.plugin),
-            'SingleInt':    SemanticTypeRecord(semantic_type=SingleInt,
-                                               plugin=self.plugin),
-            'C1':           SemanticTypeRecord(semantic_type=C1,
-                                               plugin=self.plugin),
-            'C2':           SemanticTypeRecord(semantic_type=C2,
-                                               plugin=self.plugin),
-            'C3':           SemanticTypeRecord(semantic_type=C3,
-                                               plugin=self.plugin),
-            'Foo':          SemanticTypeRecord(semantic_type=Foo,
-                                               plugin=self.plugin),
-            'Bar':          SemanticTypeRecord(semantic_type=Bar,
-                                               plugin=self.plugin),
-            'Baz':          SemanticTypeRecord(semantic_type=Baz,
-                                               plugin=self.plugin)
+            'IntSequence1':   SemanticTypeRecord(semantic_type=IntSequence1,
+                                                 plugin=self.plugin),
+            'IntSequence2':   SemanticTypeRecord(semantic_type=IntSequence2,
+                                                 plugin=self.plugin),
+            'IntSequence3':   SemanticTypeRecord(semantic_type=IntSequence3,
+                                                 plugin=self.plugin),
+            'Mapping':        SemanticTypeRecord(semantic_type=Mapping,
+                                                 plugin=self.plugin),
+            'FourInts':       SemanticTypeRecord(semantic_type=FourInts,
+                                                 plugin=self.plugin),
+            'Kennel':         SemanticTypeRecord(semantic_type=Kennel,
+                                                 plugin=self.plugin),
+            'Dog':            SemanticTypeRecord(semantic_type=Dog,
+                                                 plugin=self.plugin),
+            'Cat':            SemanticTypeRecord(semantic_type=Cat,
+                                                 plugin=self.plugin),
+            'SingleInt':      SemanticTypeRecord(semantic_type=SingleInt,
+                                                 plugin=self.plugin),
+            'C1':             SemanticTypeRecord(semantic_type=C1,
+                                                 plugin=self.plugin),
+            'C2':             SemanticTypeRecord(semantic_type=C2,
+                                                 plugin=self.plugin),
+            'C3':             SemanticTypeRecord(semantic_type=C3,
+                                                 plugin=self.plugin),
+            'Foo':            SemanticTypeRecord(semantic_type=Foo,
+                                                 plugin=self.plugin),
+            'Bar':            SemanticTypeRecord(semantic_type=Bar,
+                                                 plugin=self.plugin),
+            'Baz':            SemanticTypeRecord(semantic_type=Baz,
+                                                 plugin=self.plugin),
+            'AscIntSequence': SemanticTypeRecord(semantic_type=AscIntSequence,
+                                                 plugin=self.plugin),
+            'Squid':          SemanticTypeRecord(semantic_type=Squid,
+                                                 plugin=self.plugin),
+            'Octopus':        SemanticTypeRecord(semantic_type=Octopus,
+                                                 plugin=self.plugin),
+            'Cuttlefish':     SemanticTypeRecord(semantic_type=Cuttlefish,
+                                                 plugin=self.plugin),
         }
 
         self.assertEqual(types, exp)
@@ -98,7 +132,7 @@ class TestPluginManager(unittest.TestCase):
             'Kennel[Cat]':  SemanticTypeRecord(semantic_type=Kennel[Cat],
                                                plugin=self.plugin),
             'SingleInt':    SemanticTypeRecord(semantic_type=SingleInt,
-                                               plugin=self.plugin)
+                                               plugin=self.plugin),
         }
 
         self.assertLessEqual(exp.keys(), types.keys())
@@ -139,6 +173,11 @@ class TestPluginManager(unittest.TestCase):
             'MappingDirectoryFormat':
                 FormatRecord(format=MappingDirectoryFormat,
                              plugin=self.plugin),
+            'Cephalapod':
+                FormatRecord(format=Cephalapod, plugin=self.plugin),
+            'CephalapodDirectoryFormat':
+                FormatRecord(format=CephalapodDirectoryFormat,
+                             plugin=self.plugin),
         }
 
         obs = self.pm.get_formats()
