@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -31,163 +31,169 @@ class TestUsage(TestCaseUsage):
         action = self.plugin.actions['concatenate_ints']
         use = usage.DiagnosticUsage()
         action.examples['concatenate_ints_simple'](use)
+        records = use._get_records()
 
-        self.assertEqual(5, len(use.recorder))
+        self.assertEqual(5, len(records))
 
-        obs1, obs2, obs3, obs4, obs5 = use.recorder
+        obs1, obs2, obs3, obs4, obs5 = records.values()
 
-        self.assertEqual('init_data', obs1['source'],
-                         use._get_record(obs1['ref']).source)
-        self.assertEqual('init_data', obs2['source'],
-                         use._get_record(obs2['ref']).source)
-        self.assertEqual('init_data', obs3['source'],
-                         use._get_record(obs3['ref']).source)
-        self.assertEqual('comment', obs4['source'])
-        self.assertEqual('action', obs5['source'])
+        self.assertEqual('init_data', obs1.source)
+        self.assertEqual('init_data', obs2.source)
+        self.assertEqual('init_data', obs3.source)
+        self.assertEqual('comment', obs4.source)
+        self.assertEqual('action', obs5.source)
 
-        self.assertTrue('basic usage' in obs4['text'])
+        self.assertTrue('basic usage' in obs4.result['text'])
 
-        self.assertEqual('dummy_plugin', obs5['action'].plugin_id)
-        self.assertEqual('concatenate_ints', obs5['action'].action_id)
-        self.assertEqual({'int1': 4, 'int2': 2, 'ints1': 'ints_a',
-                          'ints2': 'ints_b', 'ints3': 'ints_c'},
-                         obs5['input_opts'])
-        self.assertEqual({'concatenated_ints': 'ints_d'}, obs5['output_opts'])
+        self.assertEqual('dummy_plugin', obs5.result['plugin_id'])
+        self.assertEqual('concatenate_ints', obs5.result['action_id'])
+        self.assertEqual({'int1': 4, 'int2': 2,
+                          'ints1': {'ref': 'ints_a', 'source': 'init_data'},
+                          'ints2': {'ref': 'ints_b', 'source': 'init_data'},
+                          'ints3': {'ref': 'ints_c', 'source': 'init_data'}},
+                         obs5.result['input_opts'])
+        self.assertEqual({'concatenated_ints': 'ints_d'},
+                         obs5.result['output_opts'])
 
     def test_chained(self):
         action = self.plugin.actions['concatenate_ints']
         use = usage.DiagnosticUsage()
         action.examples['concatenate_ints_complex'](use)
+        records = use._get_records()
 
-        self.assertEqual(7, len(use.recorder))
+        self.assertEqual(7, len(records))
 
-        obs1, obs2, obs3, obs4, obs5, obs6, obs7 = use.recorder
+        obs1, obs2, obs3, obs4, obs5, obs6, obs7 = records.values()
 
-        self.assertEqual('init_data', obs1['source'],
-                         use._get_record(obs1['ref']).source)
-        self.assertEqual('init_data', obs2['source'],
-                         use._get_record(obs2['ref']).source)
-        self.assertEqual('init_data', obs3['source'],
-                         use._get_record(obs3['ref']).source)
-        self.assertEqual('comment', obs4['source'])
-        self.assertEqual('action', obs5['source'])
-        self.assertEqual('comment', obs6['source'])
-        self.assertEqual('action', obs7['source'])
+        self.assertEqual('init_data', obs1.source)
+        self.assertEqual('init_data', obs2.source)
+        self.assertEqual('init_data', obs3.source)
+        self.assertEqual('comment', obs4.source)
+        self.assertEqual('action', obs5.source)
+        self.assertEqual('comment', obs6.source)
+        self.assertEqual('action', obs7.source)
 
-        self.assertTrue('chained usage (pt 1)' in obs4['text'])
+        self.assertTrue('chained usage (pt 1)' in obs4.result['text'])
 
-        self.assertEqual('dummy_plugin', obs5['action'].plugin_id)
-        self.assertEqual('concatenate_ints', obs5['action'].action_id)
-        self.assertEqual({'int1': 4, 'int2': 2, 'ints1': 'ints_a',
-                          'ints2': 'ints_b', 'ints3': 'ints_c'},
-                         obs5['input_opts'])
-        self.assertEqual({'concatenated_ints': 'ints_d'}, obs5['output_opts'])
+        self.assertEqual('dummy_plugin', obs5.result['plugin_id'])
+        self.assertEqual('concatenate_ints', obs5.result['action_id'])
+        self.assertEqual({'int1': 4, 'int2': 2,
+                          'ints1': {'ref': 'ints_a', 'source': 'init_data'},
+                          'ints2': {'ref': 'ints_b', 'source': 'init_data'},
+                          'ints3': {'ref': 'ints_c', 'source': 'init_data'}},
+                         obs5.result['input_opts'])
+        self.assertEqual({'concatenated_ints': 'ints_d'},
+                         obs5.result['output_opts'])
 
-        self.assertTrue('chained usage (pt 2)' in obs6['text'])
+        self.assertTrue('chained usage (pt 2)' in obs6.result['text'])
 
-        self.assertEqual('dummy_plugin', obs7['action'].plugin_id)
-        self.assertEqual('concatenate_ints', obs7['action'].action_id)
-        self.assertEqual({'int1': 41, 'int2': 0, 'ints1': 'ints_d',
-                          'ints2': 'ints_b', 'ints3': 'ints_c'},
-                         obs7['input_opts'])
+        self.assertEqual('dummy_plugin', obs7.result['plugin_id'])
+        self.assertEqual('concatenate_ints', obs7.result['action_id'])
+        exp7 = {'int1': 41, 'int2': 0,
+                'ints1': {'action_id': 'concatenate_ints',
+                          'input_opts': {'int1': 4, 'int2': 2,
+                                         'ints1': {'ref': 'ints_a',
+                                                   'source': 'init_data'},
+                                         'ints2': {'ref': 'ints_b',
+                                                   'source': 'init_data'},
+                                         'ints3': {'ref': 'ints_c',
+                                                   'source': 'init_data'}},
+                          'output_opt': 'concatenated_ints',
+                          'output_opts': {'concatenated_ints': 'ints_d'},
+                          'plugin_id': 'dummy_plugin',
+                          'source': 'action'},
+                'ints2': {'ref': 'ints_b', 'source': 'init_data'},
+                'ints3': {'ref': 'ints_c', 'source': 'init_data'}}
+        self.assertEqual(exp7, obs7.result['input_opts'])
         self.assertEqual({'concatenated_ints': 'concatenated_ints'},
-                         obs7['output_opts'])
+                         obs7.result['output_opts'])
 
     def test_comments_only(self):
         action = self.plugin.actions['concatenate_ints']
         use = usage.DiagnosticUsage()
         action.examples['comments_only'](use)
+        records = use._get_records()
 
-        self.assertEqual(2, len(use.recorder))
+        self.assertEqual(2, len(records))
 
-        obs1, obs2 = use.recorder
+        obs1, obs2 = records.values()
 
-        self.assertEqual('comment', obs1['source'])
-        self.assertEqual('comment', obs2['source'])
+        self.assertEqual('comment', obs1.source)
+        self.assertEqual('comment', obs2.source)
 
-        self.assertEqual('comment 1', obs1['text'])
-        self.assertEqual('comment 2', obs2['text'])
+        self.assertEqual('comment 1', obs1.result['text'])
+        self.assertEqual('comment 2', obs2.result['text'])
 
     def test_metadata_merging(self):
         action = self.plugin.actions['identity_with_metadata']
         use = usage.DiagnosticUsage()
         action.examples['identity_with_metadata_merging'](use)
+        records = use._get_records()
 
-        self.assertEqual(5, len(use.recorder))
+        self.assertEqual(5, len(records))
 
-        obs1, obs2, obs3, obs4, obs5 = use.recorder
+        obs1, obs2, obs3, obs4, obs5 = records.values()
 
-        self.assertEqual('init_data', obs1['source'],
-                         use._get_record(obs1['ref']).source)
-        self.assertEqual('init_data', obs2['source'],
-                         use._get_record(obs2['ref']).source)
-        self.assertEqual('init_data', obs3['source'],
-                         use._get_record(obs3['ref']).source)
-        self.assertEqual('merge_metadata', obs4['source'],
-                         use._get_record(obs4['ref']).source)
-        self.assertEqual('action', obs5['source'])
+        self.assertEqual('init_data', obs1.source)
+        self.assertEqual('init_metadata', obs2.source)
+        self.assertEqual('init_metadata', obs3.source)
+        self.assertEqual('merge_metadata', obs4.source)
+        self.assertEqual('action', obs5.source)
 
     def test_get_metadata_column(self):
         action = self.plugin.actions['identity_with_metadata_column']
         use = usage.DiagnosticUsage()
         action.examples['identity_with_metadata_column_get_mdc'](use)
+        records = use._get_records()
 
-        self.assertEqual(4, len(use.recorder))
+        self.assertEqual(4, len(records))
 
-        obs1, obs2, obs3, obs4 = use.recorder
+        obs1, obs2, obs3, obs4 = records.values()
 
-        self.assertEqual('init_data', obs1['source'],
-                         use._get_record(obs1['ref']).source)
-        self.assertEqual('init_data', obs2['source'],
-                         use._get_record(obs2['ref']).source)
-        self.assertEqual('get_metadata_column', obs3['source'],
-                         use._get_record(obs3['ref']).source)
-        self.assertEqual('action', obs4['source'])
+        self.assertEqual('init_data', obs1.source)
+        self.assertEqual('init_metadata', obs2.source)
+        self.assertEqual('get_metadata_column', obs3.source)
+        self.assertEqual('action', obs4.source)
 
     def test_use_init_collection_data(self):
         action = self.plugin.actions['variadic_input_method']
         use = usage.DiagnosticUsage()
         action.examples['variadic_input_simple'](use)
+        records = use._get_records()
 
-        self.assertEqual(len(use.recorder), 7)
+        self.assertEqual(7, len(records))
 
-        obs1, obs2, obs3, obs4, obs5, obs6, obs7 = use.recorder
+        obs1, obs2, obs3, obs4, obs5, obs6, obs7 = records.values()
 
-        self.assertEqual('init_data', obs1['source'],
-                         use._get_record(obs1['ref']).source)
-        self.assertEqual('init_data', obs2['source'],
-                         use._get_record(obs2['ref']).source)
-        self.assertEqual('init_data_collection', obs3['source'],
-                         use._get_record(obs3['ref']).source)
+        self.assertEqual('init_data', obs1.source)
+        self.assertEqual('init_data', obs2.source)
+        self.assertEqual('init_data_collection', obs3.source)
 
-        self.assertEqual('init_data', obs4['source'],
-                         use._get_record(obs4['ref']).source)
-        self.assertEqual('init_data', obs5['source'],
-                         use._get_record(obs5['ref']).source)
-        self.assertEqual('init_data_collection', obs6['source'],
-                         use._get_record(obs6['ref']).source)
-        self.assertEqual('action', obs7['source'])
+        self.assertEqual('init_data', obs4.source)
+        self.assertEqual('init_data', obs5.source)
+        self.assertEqual('init_data_collection', obs6.source)
+        self.assertEqual('action', obs7.source)
 
-        self.assertEqual(set, type(obs7['input_opts']['nums']))
+        self.assertEqual(set, type(obs7.result['input_opts']['nums']))
 
-        self.assertIn('ints', obs7['input_opts']['ints'])
-        self.assertIn('int_set', obs7['input_opts']['int_set'])
+        self.assertEqual('ints', obs7.result['input_opts']['ints'][0]['ref'])
+        self.assertEqual('int_set',
+                         obs7.result['input_opts']['int_set'][0]['ref'])
 
     def test_optional_inputs(self):
         action = self.plugin.actions['optional_artifacts_method']
         use = usage.DiagnosticUsage()
+        records = use._get_records()
 
         action.examples['optional_inputs'](use)
 
-        self.assertEqual(5, len(use.recorder))
+        self.assertEqual(3, len(records))
 
-        obs1, obs2, obs3, obs4, obs5 = use.recorder
-        self.assertEqual('init_data', obs1['source'],
-                         use._get_record(obs1['ref']).source)
-        self.assertEqual('action', obs2['source'])
-        self.assertEqual('action', obs3['source'])
-        self.assertEqual('action', obs4['source'])
-        self.assertEqual('action', obs5['source'])
+        obs1, obs2, obs3 = records.values()
+
+        self.assertEqual('init_data', obs1.source)
+        self.assertEqual('action', obs2.source)
+        self.assertEqual('action', obs3.source)
 
 
 class TestUsageAction(TestCaseUsage):
@@ -426,3 +432,26 @@ class TestExecutionUsage(TestCaseUsage):
         self.assertIn(single_int1.result, int_set.result)
         self.assertIn(single_int2.result, int_set.result)
         self.assertIsInstance(out.result, Artifact)
+
+    def test_variadic_input_simple_async(self):
+        use = usage.ExecutionUsage(asynchronous=True)
+        action = self.plugin.actions['variadic_input_method']
+        action.examples['variadic_input_simple'](use)
+        ints_a = use._get_record('ints_a')
+        ints_b = use._get_record('ints_b')
+        ints = use._get_record('ints')
+        single_int1 = use._get_record('single_int1')
+        single_int2 = use._get_record('single_int2')
+        int_set = use._get_record('int_set')
+        out = use._get_record('out')
+        self.assertIsInstance(ints_a.result, Artifact)
+        self.assertIsInstance(ints_b.result, Artifact)
+        self.assertIsInstance(ints.result, list)
+        self.assertEqual(ints.result[0], ints_a.result)
+        self.assertEqual(ints.result[1], ints_b.result)
+        self.assertIsInstance(single_int1.result, Artifact)
+        self.assertIsInstance(single_int2.result, Artifact)
+        self.assertIsInstance(int_set.result, set)
+        self.assertIn(single_int1.result, int_set.result)
+        self.assertIn(single_int2.result, int_set.result)
+        self.assertIsInstance(out.result, Artifact)
